@@ -10,17 +10,17 @@
 #include "kerfuffle/archiveentry.h"
 #include "kerfuffle/kerfuffle_export.h"
 
-#include <QDir>
 #include <QDate>
+#include <QDir>
 #include <QTime>
 
 K_PLUGIN_CLASS_WITH_JSON(CliPlugin, "kerfuffle_cli.json")
 
 CliPlugin::CliPlugin(QObject *parent, const QVariantList &args)
-    : CliInterface(parent, args),
-      m_isFirstLine(true),
-      m_incontent(false),
-      m_isPasswordProtected(false)
+    : CliInterface(parent, args)
+    , m_isFirstLine(true)
+    , m_incontent(false)
+    , m_isPasswordProtected(false)
 {
     qCDebug(ARK) << "Loaded cli-example plugin";
 }
@@ -38,20 +38,20 @@ ParameterList CliPlugin::parameterList() const
         p[ListProgram] = p[ExtractProgram] = p[DeleteProgram] = p[AddProgram] = QLatin1String("rar");
 
         p[ListArgs] = QStringList() << QLatin1String("v") << QLatin1String("-c-") << QLatin1String("$Archive");
-        p[ExtractArgs] = QStringList() << QLatin1String("-p-") << QLatin1String("$PreservePathSwitch") << QLatin1String("$PasswordSwitch") << QLatin1String("$Archive") << QLatin1String("$Files");
+        p[ExtractArgs] = QStringList() << QLatin1String("-p-") << QLatin1String("$PreservePathSwitch") << QLatin1String("$PasswordSwitch")
+                                       << QLatin1String("$Archive") << QLatin1String("$Files");
         p[PreservePathSwitch] = QStringList() << QLatin1String("x") << QLatin1String("e");
         p[PasswordSwitch] = QStringList() << QLatin1String("-p$Password");
 
         p[DeleteArgs] = QStringList() << QLatin1String("d") << QLatin1String("$Archive") << QLatin1String("$Files");
 
         p[FileExistsExpression] = QLatin1String("^(.+) already exists. Overwrite it");
-        p[FileExistsInput] = QStringList()
-                                << QLatin1String("Y") //overwrite
-                                << QLatin1String("N") //skip
-                                << QLatin1String("A") //overwrite all
-                                << QLatin1String("E") //autoskip
-                                << QLatin1String("Q") //cancel
-                                ;
+        p[FileExistsInput] = QStringList() << QLatin1String("Y") // overwrite
+                                           << QLatin1String("N") // skip
+                                           << QLatin1String("A") // overwrite all
+                                           << QLatin1String("E") // autoskip
+                                           << QLatin1String("Q") // cancel
+            ;
 
         p[AddArgs] = QStringList() << QLatin1String("a") << QLatin1String("$Archive") << QLatin1String("$Files");
 
@@ -83,10 +83,10 @@ bool CliPlugin::readListLine(const QString &line)
     // rar gives one line for the filename and a line after it with some file properties
     if (m_isFirstLine) {
         m_entryFilename = line.trimmed();
-        //m_entryFilename.chop(1); // handle newline
+        // m_entryFilename.chop(1); // handle newline
         if (!m_entryFilename.isEmpty() && m_entryFilename.at(0) == QLatin1Char('*')) {
             m_isPasswordProtected = true;
-            m_entryFilename.remove(0, 1);   // and the spaces in front
+            m_entryFilename.remove(0, 1); // and the spaces in front
         } else
             m_isPasswordProtected = false;
 
@@ -96,10 +96,9 @@ bool CliPlugin::readListLine(const QString &line)
 
     QStringList fileprops = line.split(QLatin1Char(' '), Qt::SkipEmptyParts);
     m_entryFilename = QDir::fromNativeSeparators(m_entryFilename);
-    bool isDirectory = (bool)(fileprops[ 5 ].contains(QLatin1Char('d'), Qt::CaseInsensitive));
+    bool isDirectory = (bool)(fileprops[5].contains(QLatin1Char('d'), Qt::CaseInsensitive));
 
-    QDateTime ts(QDate::fromString(fileprops[ 3 ], QLatin1String("dd-MM-yy")),
-                 QTime::fromString(fileprops[ 4 ], QLatin1String("hh:mm")));
+    QDateTime ts(QDate::fromString(fileprops[3], QLatin1String("dd-MM-yy")), QTime::fromString(fileprops[4], QLatin1String("hh:mm")));
     // rar output date with 2 digit year but QDate takes is as 19??
     // let's take 1950 is cut-off; similar to KDateTime
     if (ts.date().year() < 1950) {
@@ -113,15 +112,15 @@ bool CliPlugin::readListLine(const QString &line)
     qCDebug(ARK) << m_entryFilename << " : " << fileprops;
     Archive::Entry *e = new Archive::Entry();
     e->setProperty("fullPath", m_entryFilename);
-    e->setProperty("size", fileprops[ 0 ]);
-    e->setProperty("compressedSize", fileprops[ 1 ]);
-    e->setProperty("ratio", fileprops[ 2 ]);
+    e->setProperty("size", fileprops[0]);
+    e->setProperty("compressedSize", fileprops[1]);
+    e->setProperty("ratio", fileprops[2]);
     e->setProperty("timestamp", ts);
     e->setProperty("isDirectory", isDirectory);
-    e->setProperty("permissions", fileprops[ 5 ].remove(0, 1));
-    e->setProperty("CRC", fileprops[ 6 ]);
-    e->setProperty("method", fileprops[ 7 ]);
-    e->setProperty("version", fileprops[ 8 ]);
+    e->setProperty("permissions", fileprops[5].remove(0, 1));
+    e->setProperty("CRC", fileprops[6]);
+    e->setProperty("method", fileprops[7]);
+    e->setProperty("version", fileprops[8]);
     e->setProperty("ssPasswordProtected", m_isPasswordProtected);
     qCDebug(ARK) << "Added entry: " << e;
 
